django_analyses.serializers.input package — django_analyses 0.0.3 documentation

# django_analyses.serializers.input package

## Subpackages

- django_analyses.serializers.input.definitions package
  - Submodules
  - django_analyses.serializers.input.definitions.boolean_input_definition module
  - django_analyses.serializers.input.definitions.directory_input_definition module
  - django_analyses.serializers.input.definitions.file_input_definition module
  - django_analyses.serializers.input.definitions.float_input_definition module
  - django_analyses.serializers.input.definitions.input_definition module
  - django_analyses.serializers.input.definitions.integer_input_definition module
  - django_analyses.serializers.input.definitions.list_input_definition module
  - django_analyses.serializers.input.definitions.string_input_definition module
  - Module contents
- django_analyses.serializers.input.types package
  - Submodules
  - django_analyses.serializers.input.types.boolean_input module
  - django_analyses.serializers.input.types.directory_input module
  - django_analyses.serializers.input.types.file_input module
  - django_analyses.serializers.input.types.float_input module
  - django_analyses.serializers.input.types.integer_input module
  - django_analyses.serializers.input.types.list_input module
  - django_analyses.serializers.input.types.string_input module
  - Module contents

## Submodules

## django_analyses.serializers.input.input module

class `django_analyses.serializers.input.input.` `InputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `django_analyses.serializers.utils.polymorphic.PolymorphicSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.input.Input`

  `get_serializer`(input_type: str) → rest_framework.serializers.Serializer

    Return a dict to map class names to their respective serializer classes. To be implemented by all PolymorphicSerializer subclasses.

`django_analyses.serializers.input.input.` `get_extra_input_serializers`() → dict

## django_analyses.serializers.input.input_specification module

class `django_analyses.serializers.input.input_specification.` `InputSpecificationSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'analysis', 'input_definitions', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.input.input_specification.InputSpecification`

## Module contents